@@ -1,7 +1,7 @@
 
 # -*- coding: utf-8 -*-
 
-__version__='1.0.1'
+__version__='1.0.2'
 
 from flask import Flask
 
@@ -13,8 +13,10 @@ from flask_cors import CORS
 
 import mysql.connector
 
+import base64
+
 app = Flask(__name__)
-CORS(app)
+CORS(app, support_credentials=True)
 
 app.config['JSONIFY_PRETTYPRINT_REGULAR'] = True    #default False
 app.config['JSON_SORT_KEYS'] = True                 #default True
@@ -101,28 +103,70 @@ def post_insert(db=None, table=None):
     assert db == request.view_args['db']
     assert table == request.view_args['table']
 
-    if not request.headers['Content-Type'] == 'application/json':
-        return jsonify(status=412, errorType="Precondition Failed"), 412
+    if request.is_json:
 
-    post = request.get_json()
+        post = request.get_json()
 
-    placeholders = ['%s'] * len(post)
+        placeholders = ['%s'] * len(post)
 
-    fields = ",".join([str(key) for key in post])
-    places = ",".join([str(key) for key in placeholders])
+        fields = ",".join([str(key) for key in post])
+        places = ",".join([str(key) for key in placeholders])
 
-    records=[]
-    for key in post:
-        records.append(post[key])
+        records=[]
+        for key in post:
+            records.append(post[key])
 
-    SQL = "INSERT INTO " +str(db)+"."+str(table)+" ("+str(fields)+") VALUES ("+str(places)+")"
+        SQL = "INSERT INTO " +str(db)+"."+str(table)+" ("+str(fields)+") VALUES ("+str(places)+")"
 
-    insert = sqlexec(SQL, records)
+        insert = sqlexec(SQL, records)
 
-    if insert > 0:
-        return jsonify(status=201, message="Created", insert=True), 201
-    else:
-        return jsonify(status=461, message="Failed Create", insert=False), 461
+        if insert > 0:
+            return jsonify(status=201, message="Created", insert=True), 201
+        else:
+            return jsonify(status=461, message="Failed Create", insert=False), 461
+
+    elif request.form:
+
+        credentials = request.form.get('credentials', None)
+
+        if credentials:
+
+            columns=[]
+            records=[]
+            for key,val in request.form.items():
+                if key == 'credentials':
+                    continue
+                columns.append(key)
+                records.append(request.form[key])
+
+            count = len(request.form) - 1
+            placeholders = ['%s'] * count
+
+            places = ",".join([str(key) for key in placeholders])
+
+            fields = ",".join([str(key) for key in columns])
+
+            base64_bytes = credentials.encode('ascii')
+            token_bytes = base64.b64decode(base64_bytes)
+            untoken = token_bytes.decode('ascii')
+
+            base64_user = untoken.split(":", 1)[0]
+            base64_pass = untoken.split(":", 1)[1]
+
+            SQL = "INSERT INTO " +str(db)+"."+str(table)+" ("+str(fields)+") VALUES ("+str(places)+")"
+
+            insert = sqlInsert(SQL, records, base64_user, base64_pass)
+
+            if insert > 0:
+                return jsonify(status=201, message="Created", method="POST", insert=True), 201
+            else:
+                return jsonify(status=461, message="Failed Create", method="POST", insert=False), 461
+
+        return jsonify(status=401, message="Unauthorized", details="No valid authentication credentials for the target resource", method="POST", insert=False), 401
+
+    else: 
+
+        return jsonify(status=417, message="Expectation Failed", details="The server cannot meet the requirements of the Expect request-header field", method="POST", insert=False), 417
 
 
 #DELETE /api/<db>/<table>/:id         # Delete a row by primary key
@@ -280,10 +324,29 @@ def sqlcommit(sql):
     cnx.close()
     return rowcount
 
-def sqlConnection():
+def sqlInsert(sql, values, user, password):
+    cnx = sqlConnection(user, password)
+    cur = cnx.cursor(buffered=True)
+    cur.execute(sql, values)
+    cnx.commit()
+    rowcount = cur.rowcount
+    cur.close()
+    cnx.close()
+    return rowcount
+
+def sqlConnection(user=None, password=None):
+
+    if not user:
+        user = request.authorization.username
+
+    if not password:
+        password = request.authorization.password
+
     config = {
-        'user':                   request.authorization.username,
-        'password':               request.authorization.password,
+        #'user':                   request.authorization.username,
+        #'password':               request.authorization.password,
+        'user':                   user,
+        'password':               password,
         'host':                   request.headers.get('X-Host', '127.0.0.1'),
         'port':               int(request.headers.get('X-Port', '3306')),
         'database':               request.headers.get('X-Db', ''),
